==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/DynamoDB/TimeToLiveSpecification.pm <==
package Paws::DynamoDB::TimeToLiveSpecification;
  use Moose;
  has AttributeName => (is => 'ro', isa => 'Str', required => 1);
  has Enabled => (is => 'ro', isa => 'Bool', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::DynamoDB::TimeToLiveSpecification

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::DynamoDB::TimeToLiveSpecification object:

  $service_obj->Method(Att1 => { AttributeName => $value, ..., Enabled => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::DynamoDB::TimeToLiveSpecification object:

  $result = $service_obj->Method(...);
  $result->Att1->AttributeName

=head1 DESCRIPTION

Represents the settings used to enable or disable Time to Live for the
specified table.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AttributeName => Str

  The name of the Time to Live attribute used to store the expiration
time for items in the table.


=head2 B<REQUIRED> Enabled => Bool

  Indicates whether Time To Live is to be enabled (true) or disabled
(false) on the table.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::DynamoDB>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/DynamoDB/TimeToLiveSpecification.pm <==
package Paws::DynamoDB::TimeToLiveSpecification;
  use Moose;
  has AttributeName => (is => 'ro', isa => 'Str', required => 1);
  has Enabled => (is => 'ro', isa => 'Bool', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::DynamoDB::TimeToLiveSpecification

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::DynamoDB::TimeToLiveSpecification object:

  $service_obj->Method(Att1 => { AttributeName => $value, ..., Enabled => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::DynamoDB::TimeToLiveSpecification object:

  $result = $service_obj->Method(...);
  $result->Att1->AttributeName

=head1 DESCRIPTION

Represents the settings used to enable or disable Time to Live for the
specified table.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AttributeName => Str

  The name of the Time to Live attribute used to store the expiration
time for items in the table.


=head2 B<REQUIRED> Enabled => Bool

  Indicates whether Time To Live is to be enabled (true) or disabled
(false) on the table.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::DynamoDB>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
